"""PyUnit tests

These tests could either be called from the command line,
or within Eclipse by the plugin PyDev / PyUnit.

* CLI: '*python setup.py test*' 

* Eclipse: Install PyDev, open the view PyUnit and proceed.


**REMARK**: For additional unit tests refer to subdirectory 'UseCases' 


30_libs
-------
Provided library modules of 'epyunit'.

"""
__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2015-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.2'
__uuid__='efed42d3-f801-4fbb-abfd-bd598d683a82'

__package__ = 'pysourceinfo_pyunit'
