# -*- coding: utf-8 -*-
"""The package 'pysourceinfo' provides a basic wrapper for Python RTTI on sourcefiles.
It is based on 'inspect'.

"""
from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.8'
__uuid__='efed42d3-f801-4fbb-abfd-bd598d683a82'

__docformat__ = "restructuredtext en"

__package__ = 'pysourceinfo'
__all__=[
    "PySourceInfo",
]

